import {Component, EventEmitter, Input, OnInit, Output} from '@angular/core';
import {
  AbstractControl,
  FormArray,
  FormControl,
  FormGroup,
  FormsModule,
  ReactiveFormsModule,
  Validators
} from "@angular/forms";
import {Hotel} from "./hotel";
import {RouterLink} from "@angular/router";
import {AddTagComponent} from "./add-tag.component";
import {NgForOf} from "@angular/common";
import {TagComponent} from "./tag.component";

@Component({
  selector: 'app-edit-hotel',
  standalone: true,
  imports: [
    FormsModule,
    ReactiveFormsModule,
    RouterLink,
    AddTagComponent,
    NgForOf,
    TagComponent
  ],
  template: `
    <ng-form [formGroup]="form" (ngSubmit)="submit()">
      <label for="name">Name</label>
      <br>
      <input id="name" type="text" formControlName="name">
      <br>
      <label for="description">Description</label>
      <br>
      <input id="description" type="text" formControlName="description">
      <br>
      <label for="price">Price</label>
      <br>
      <input id="price" type="number" formControlName="price">
      <br>
      <label for="rating">Rating</label>
      <br>
      <input id="rating" type="number" formControlName="rating" min="0" max="5">
      <br>
      <br>
      <button (click)="addTag()">+</button>
      <div formArrayName="tags">
        <div *ngFor="let tag of getTags().controls; let i = index">
          <input type="text" placeholder="tag" [formControlName]="i">
          <button (click)="deleteTag(tag)">-</button>
        </div>
      </div>
      <br>
      <br>
      <button type="submit" (click)="submit()">Submit</button>
    </ng-form>

    <button routerLink="/hotels">back</button>
  `,
})
export class EditHotelComponent implements OnInit {
  @Input()
  hotel: Hotel | null = null;

  @Output()
  updateHotel: EventEmitter<Hotel> = new EventEmitter

  form!: FormGroup

  ngOnInit(): void {
    const tags = [];

    for (const tag of this.hotel?.tags ?? []) {
      tags.push(new FormControl(tag, [Validators.required]));
    }

    console.log(tags)
    this.form = new FormGroup({
      name: new FormControl(this.hotel?.hotelName, [Validators.required]),
      description: new FormControl(this.hotel?.description, [Validators.required]),
      price: new FormControl(this.hotel?.price, [Validators.required]),
      rating: new FormControl(this.hotel?.rating, [Validators.required, Validators.min(0), Validators.max(5)]),
      tags: new FormArray(tags),
    })
  }

  submit() {
    if (!this.form.valid) {
      console.error('Form invalid');

    }

    const hotel: Hotel = {
      imageUrl: this.hotel?.imageUrl ?? "",
      hotelName: this.form.value.name,
      description: this.form.value.description,
      price: this.form.value.price,
      rating: this.form.value.rating,
      id: this.hotel?.id ?? 0,
      tags: this.form.value.tags ?? []
    };
    console.log(hotel)
    this.updateHotel.emit(hotel)

    this.hotel = hotel;
  }

  getTags() {
    return this.form.controls['tags'] as FormArray;
  }

  addTag() {
    this.getTags().push(new FormControl('', [Validators.required]));
  }

  deleteTag(tagElement: AbstractControl) {
    this.getTags().removeAt(this.getTags().controls.indexOf(tagElement));
  }
}
