import {Component, inject, OnInit} from "@angular/core";
import {Hotel} from "./hotel"
import {CurrencyPipe, NgOptimizedImage} from "@angular/common";
import {Lang} from "../idek/lang";
import {StarComponent} from "../star/star.component";
import {ActivatedRoute} from "@angular/router";
import {HotelService} from "../service/hotel.service";
import {catchError, EMPTY} from "rxjs";
import {EditHotelComponent} from "./edit-hotel.component";
import {DeleteHotelComponent} from "./delete-hotel.component";


@Component({
  standalone: true,
  selector: 'app-hotel',
  imports: [
    CurrencyPipe,
    StarComponent,
    NgOptimizedImage,
    EditHotelComponent,
    DeleteHotelComponent
  ],
  template: `
    <div style="border: white 2px; border-radius: 2px">
      @if (hotel && !alert) {
        <app-edit-hotel [hotel]="hotel" (updateHotel)="update($event)" />
        <app-delete-hotel [id]="hotel.id" />
      } @else if(alert) {
        <h2>{{alert}}</h2>
      } @else {
        <h2>loading</h2>
      }

    </div>
  `
})
export class HotelComponent implements OnInit {
  protected currency: Lang = {name: 'de', code: 'de-DE', currency: 'EUR'}

  protected hotel!: Hotel;

  protected alert: string|undefined

  private route: ActivatedRoute = inject(ActivatedRoute);

  private hotelService: HotelService = inject(HotelService);

  ngOnInit(): void {
    const hotelId = this.route.snapshot.params['hotelId'];
    this.hotelService.getHotelById(hotelId)
      .pipe(catchError((err) => {
      this.alert = `Hotel could not be retrieved: ${err.message}`
      return EMPTY;
    }))
      .subscribe({next: (hotel: Hotel) => {this.hotel = hotel}})
  }

  update(hotel: Hotel): void {
    this.hotelService.updateHotelById(hotel).subscribe()
  }
}
